==> h-vue3-components-dev-1.0.11.tgz: package/es/src/packages/components/forms/switch/Switch.vue.js <==
import { inject as r, ref as d, computed as w, resolveComponent as g, openBlock as x, createBlock as y, mergeProps as b, unref as i, isRef as _, toHandlers as A } from "vue";
import n from "../../../utils/formUtil.js";
import "./Switch.vue2.js";
const T = {
  __name: "Switch",
  props: {
    option: {
      type: Object,
      default() {
        return {};
      }
    },
    event: {
      type: Object,
      default() {
        return {};
      }
    },
    modelValue: String | Number,
    isEdit: {
      type: Boolean,
      default: !1
    }
  },
  emits: ["update:modelValue", "change"],
  setup(m, { emit: h }) {
    r("formData");
    const c = r("changeFieldData"), e = m, o = d(!1);
    (e.option.readOnly || e.option.switchValue.readOnly || e.option.disabled) && (o.value = !0), e.isEdit && (o.value = !1);
    const a = d(!1);
    s(e.modelValue);
    const u = h, l = w({
      get: () => e.modelValue,
      set: (t) => {
        u("update:modelValue", t);
      }
    });
    function v(t) {
      s(t), u("change", t), c && c(e.option.fieldName, t);
    }
    function s(t) {
      t == e.option.switchValue.activeValue && e.option.switchValue.activeText || t == e.option.switchValue.inActiveValue && e.option.switchValue.inActiveText ? a.value = !0 : a.value = !1;
    }
    return (t, p) => {
      const V = g("el-switch");
      return x(), y(V, b({
        modelValue: i(l),
        "onUpdate:modelValue": p[0] || (p[0] = (f) => _(l) ? l.value = f : null),
        "active-value": i(n).isEmpty(e.option.switchValue.activeValue) ? 0 : e.option.switchValue.activeValue,
        "inactive-value": i(n).isEmpty(e.option.switchValue.inActiveValue) ? 1 : e.option.switchValue.inActiveValue,
        "active-text": e.option.switchValue.activeText,
        "inactive-text": e.option.switchValue.inActiveText,
        placeholder: i(n).isEmpty(e.option.placeholder) ? "" : e.option.placeholder,
        disabled: i(o)
      }, A(e.event), {
        onChange: v,
        class: {
          "h-auto-switch": i(a)
        }
      }), null, 16, ["modelValue", "active-value", "inactive-value", "active-text", "inactive-text", "placeholder", "disabled", "class"]);
    };
  }
};
export {
  T as default
};

==> h-vue3-components-dev-1.0.31.tgz: package/es/src/packages/components/forms/switch/Switch.vue.js <==
import "../../../../../node_modules/element-plus/theme-chalk/base.css.js";
import "../../../../../node_modules/element-plus/theme-chalk/el-switch.css.js";
import { inject as r, ref as d, computed as w, openBlock as g, createBlock as x, mergeProps as y, unref as i, isRef as b, toHandlers as _ } from "vue";
import n from "../../../utils/formUtil.js";
import "./Switch.vue2.js";
import { ElSwitch as E } from "../../../../../node_modules/element-plus/es/components/switch/index.js";
const B = {
  __name: "Switch",
  props: {
    option: {
      type: Object,
      default() {
        return {};
      }
    },
    event: {
      type: Object,
      default() {
        return {};
      }
    },
    modelValue: String | Number,
    isEdit: {
      type: Boolean,
      default: !1
    }
  },
  emits: ["update:modelValue", "change"],
  setup(m, { emit: h }) {
    r("formData");
    const c = r("changeFieldData"), e = m, o = d(!1);
    (e.option.readOnly || e.option.switchValue.readOnly || e.option.disabled) && (o.value = !0), e.isEdit && (o.value = !1);
    const a = d(!1);
    s(e.modelValue);
    const u = h, l = w({
      get: () => e.modelValue,
      set: (t) => {
        u("update:modelValue", t);
      }
    });
    function v(t) {
      s(t), u("change", t), c && c(e.option.fieldName, t);
    }
    function s(t) {
      t == e.option.switchValue.activeValue && e.option.switchValue.activeText || t == e.option.switchValue.inActiveValue && e.option.switchValue.inActiveText ? a.value = !0 : a.value = !1;
    }
    return (t, p) => {
      const V = E;
      return g(), x(V, y({
        modelValue: i(l),
        "onUpdate:modelValue": p[0] || (p[0] = (f) => b(l) ? l.value = f : null),
        "active-value": i(n).isEmpty(e.option.switchValue.activeValue) ? 0 : e.option.switchValue.activeValue,
        "inactive-value": i(n).isEmpty(e.option.switchValue.inActiveValue) ? 1 : e.option.switchValue.inActiveValue,
        "active-text": e.option.switchValue.activeText,
        "inactive-text": e.option.switchValue.inActiveText,
        placeholder: i(n).isEmpty(e.option.placeholder) ? "" : e.option.placeholder,
        disabled: i(o)
      }, _(e.event), {
        onChange: v,
        class: {
          "h-auto-switch": i(a)
        }
      }), null, 16, ["modelValue", "active-value", "inactive-value", "active-text", "inactive-text", "placeholder", "disabled", "class"]);
    };
  }
};
export {
  B as default
};
